@@ -13,6 +13,4 @@ namespace Vpn\Portal\Cfg\Exception;
 
 use Exception;
 
-class ConfigException extends Exception
-{
-}
+class ConfigException extends Exception {}
