@@ -34,4 +34,14 @@ class OidcAuthConfig
     {
         return $this->requireStringArray('permissionAttributeList', []);
     }
+
+    /**
+     * Set this to the value of OIDCClaimDelimiter you use in your Apache
+     * configuration. The default is ",", but this won't work well if the
+     * values of your permissions themselves contain a ",".
+     */
+    public function claimDelimiter(): string
+    {
+        return $this->requireString('claimDelimiter', ',');
+    }
 }
