@@ -34,4 +34,9 @@ class ShibAuthConfig
     {
         return $this->requireStringArray('permissionAttributeList', []);
     }
+
+    public function encodedAttributeValues(): bool
+    {
+        return $this->requireBool('encodedAttributeValues', false);
+    }
 }
