@@ -32,6 +32,7 @@ class ConfigCheck
 
         // global issues
         self::verifyMbStringFuncOverload($globalProblemList);
+        self::verifyDuplicateProfileId($config, $globalProblemList);
         self::verifyNotSupportedConfigKeys($config, $globalProblemList);
         self::verifyNotSupportedWireGuardConfigKeys($config->wireGuardConfig(), $globalProblemList);
 
@@ -41,6 +42,7 @@ class ConfigCheck
             self::verifyValidProfileId($profileConfig, $problemList);
             self::verifyNotSupportedProfileConfigKeys($profileConfig, $problemList);
             self::verifyDefaultGatewayHasDnsServerList($profileConfig, $problemList);
+            self::verifyNoSearchDomainWhenDefaultGateway($profileConfig, $problemList);
             self::verifyRangeOverlap($profileConfig, $usedRangeList, $problemList);
             self::verifyRoutesAndExcludeRoutesAreNormalized($profileConfig, $problemList);
             self::verifyDnsRouteIsPushedWhenNotDefaultGateway($profileConfig, $problemList);
@@ -68,6 +70,17 @@ class ConfigCheck
         }
     }
 
+    private static function verifyDuplicateProfileId(Config $config, array &$globalProblemList): void
+    {
+        $profileIdList = [];
+        foreach ($config->profileConfigList() as $profileConfig) {
+            if (in_array($profileConfig->profileId(), $profileIdList, true)) {
+                $globalProblemList[] = sprintf('duplicate Profile ID: %s', $profileConfig->profileId());
+            }
+            $profileIdList[] = $profileConfig->profileId();
+        }
+    }
+
     private static function verifyNotSupportedConfigKeys(Config $config, array &$globalProblemList): void
     {
         $unsupportedConfigKeys = $config->unsupportedConfigKeys();
@@ -185,6 +198,17 @@ class ConfigCheck
         }
     }
 
+    private static function verifyNoSearchDomainWhenDefaultGateway(ProfileConfig $profileConfig, array &$profileProblemList): void
+    {
+        if (!$profileConfig->defaultGateway()) {
+            return;
+        }
+
+        if (0 !== count($profileConfig->dnsSearchDomainList())) {
+            $profileProblemList[] = 'for "defaultGateway" profiles, setting "dnsSearchDomainList" has no effect';
+        }
+    }
+
     private static function verifyDnsHasSearchDomainWhenNotDefaultGateway(ProfileConfig $profileConfig, array &$profileProblemList): void
     {
         if ($profileConfig->defaultGateway()) {
