@@ -31,11 +31,11 @@ class ConnectionHooks implements ConnectionHookInterface
         $this->connectionHookList[] = $connectionHook;
     }
 
-    public function connect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp): void
+    public function connect(NodeInfo $nodeInfo, string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp, ?IpInfo $ipInfo): void
     {
         foreach ($this->connectionHookList as $connectionHook) {
             try {
-                $connectionHook->connect($userId, $profileId, $vpnProto, $connectionId, $ipFour, $ipSix, $originatingIp);
+                $connectionHook->connect($nodeInfo, $userId, $profileId, $vpnProto, $connectionId, $ipFour, $ipSix, $originatingIp, $ipInfo);
             } catch (ConnectionHookException $e) {
                 $this->logger->warning(sprintf('[%s,%s] %s', __METHOD__, get_class($connectionHook), $e->getMessage()));
 
@@ -44,11 +44,12 @@ class ConnectionHooks implements ConnectionHookInterface
         }
     }
 
-    public function disconnect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, int $bytesIn, int $bytesOut): void
+    public function disconnect(NodeInfo $nodeInfo, string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, int $bytesIn, int $bytesOut): void
     {
         foreach ($this->connectionHookList as $connectionHook) {
             try {
                 $connectionHook->disconnect(
+                    $nodeInfo,
                     $userId,
                     $profileId,
                     $vpnProto,
