@@ -16,6 +16,7 @@ use DateTimeImmutable;
 use Vpn\Portal\Cfg\Config;
 use Vpn\Portal\Cfg\ProfileConfig;
 use Vpn\Portal\Exception\ConnectionManagerException;
+use Vpn\Portal\Exception\IpException;
 use Vpn\Portal\OpenVpn\ClientConfig as OpenVpnClientConfig;
 use Vpn\Portal\WireGuard\ClientConfig as WireGuardClientConfig;
 
@@ -42,16 +43,16 @@ class ConnectionManager
     }
 
     /**
-     * @return array<array{node_number:int,node_url:string,node_info:?array{rel_load_average:array<int>,load_average:array<float>,cpu_count:int,node_uptime:int}}>
+     * @return array<array{node_number:int,node_url:string,node_info:?array{connection_count:int,rel_load_average:array<int>,load_average:array<float>,cpu_count:int,node_uptime:int,maintenance_mode:bool}}>
      */
-    public function nodeInfo(): array
+    public function nodeInfo(bool $connectionCount = false): array
     {
         $nodeInfoList = [];
         foreach ($this->config->nodeNumberUrlList() as $nodeNumber => $nodeUrl) {
             $nodeInfoList[] = [
                 'node_number' => $nodeNumber,
                 'node_url' => $nodeUrl,
-                'node_info' => $this->vpnDaemon->nodeInfo($nodeUrl),
+                'node_info' => $this->vpnDaemon->nodeInfo($nodeUrl, $connectionCount),
             ];
         }
 
@@ -215,25 +216,28 @@ class ConnectionManager
     }
 
     /**
-     * @param array{wireguard:bool,openvpn:bool} $clientProtoSupport
+     * @param array{openvpn+udp:bool,openvpn+tcp:bool,wireguard+udp:bool,wireguard+tcp:bool} $clientProtoSupport
      */
     public function connect(ServerInfo $serverInfo, ProfileConfig $profileConfig, string $userId, array $clientProtoSupport, string $displayName, DateTimeImmutable $expiresAt, bool $preferTcp, ?string $publicKey, ?string $authKey): ClientConfigInterface
     {
-        foreach (Protocol::determine($profileConfig, $clientProtoSupport, $publicKey, $preferTcp) as $vpnProto) {
+        $vpnProtoList = Protocol::determine($this->config->wireGuardConfig(), $profileConfig, $clientProtoSupport, $publicKey, $preferTcp);
+        foreach ($vpnProtoList as $vpnProto) {
             switch ($vpnProto) {
-                case 'wireguard':
+                case 'wireguard+udp':
+                case 'wireguard+tcp':
                     /**
                      * Protocol::determine makes sure $publicKey is NOT null.
                      *
                      * @var string $publicKey
                      */
-                    if (null === $wireGuardConfig = $this->wConnect($serverInfo, $profileConfig, $userId, $displayName, $expiresAt, $publicKey, $authKey)) {
+                    if (null === $wireGuardConfig = $this->wConnect($serverInfo, $profileConfig, $userId, $displayName, $expiresAt, $vpnProto, $publicKey, $authKey)) {
                         break;
                     }
 
                     return $wireGuardConfig;
-                case 'openvpn':
-                    if (null === $openVpnConfig = $this->oConnect($serverInfo, $profileConfig, $userId, $displayName, $expiresAt, $preferTcp, $authKey)) {
+                case 'openvpn+udp':
+                case 'openvpn+tcp':
+                    if (null === $openVpnConfig = $this->oConnect($serverInfo, $profileConfig, $userId, $displayName, $expiresAt, $vpnProto, $authKey)) {
                         break;
                     }
 
@@ -241,7 +245,12 @@ class ConnectionManager
             }
         }
 
-        throw new ConnectionManagerException('unable to connect using any of the common supported VPN protocols');
+        throw new ConnectionManagerException(
+            sprintf(
+                'unable to obtain a VPN configuration for any of protocol+transport [%s]',
+                0 !== count($vpnProtoList) ? implode(',', $vpnProtoList) : 'None'
+            )
+        );
     }
 
     /**
@@ -444,8 +453,19 @@ class ConnectionManager
         if (null !== $openConnectionInfo = $this->storage->openConnectionInfo($publicKey)) {
             $this->logger->debug(sprintf('%s: removing peer (reason: %s) [%s,%d,%s]', __METHOD__, $disconnectReason, $openConnectionInfo['profile_id'], $nodeNumber, $publicKey));
             $this->wDisconnect($openConnectionInfo['user_id'], $openConnectionInfo['profile_id'], $nodeNumber, $publicKey, $openConnectionInfo['ip_four'], $openConnectionInfo['ip_six']);
+
+            return;
         }
-        // XXX should we log when there is no open connection for this public key in the connection_log table?
+
+        // we have a WireGuard peer that is registered in the node, but for
+        // which we have NO (open) connection info, delete it
+        $this->logger->debug(sprintf('%s: removing peer without open connection (reason: %s) [%d,%s]', __METHOD__, $disconnectReason, $nodeNumber, $publicKey));
+        if (null === $nodeUrl = $this->nodeUrl($nodeNumber)) {
+            $this->logger->warning(sprintf('node "%d" does not exist (anymore)', $nodeNumber));
+
+            return;
+        }
+        $this->vpnDaemon->wPeerRemove($nodeUrl, $publicKey);
     }
 
     private function wDisconnect(string $userId, string $profileId, int $nodeNumber, string $publicKey, string $ipFour, string $ipSix): void
@@ -464,7 +484,13 @@ class ConnectionManager
             $bytesOut = $daemonPeerInfo['bytes_out'];
         }
 
-        $this->connectionHook->disconnect($userId, $profileId, 'wireguard', $publicKey, $ipFour, $ipSix, $bytesIn, $bytesOut);
+        $profileConfig = $this->config->profileConfig($profileId);
+        $nodeInfo = new NodeInfo(
+            $nodeNumber,
+            $profileConfig->nodeUrl($nodeNumber),
+            $profileConfig->hostName($nodeNumber)
+        );
+        $this->connectionHook->disconnect($nodeInfo, $userId, $profileId, 'wireguard', $publicKey, $ipFour, $ipSix, $bytesIn, $bytesOut);
     }
 
     private function oDisconnect(string $profileId, int $nodeNumber, string $commonName): void
@@ -479,39 +505,57 @@ class ConnectionManager
         $this->vpnDaemon->oDisconnectClient($nodeUrl, $commonName);
     }
 
-    private function wConnect(ServerInfo $serverInfo, ProfileConfig $profileConfig, string $userId, string $displayName, DateTimeImmutable $expiresAt, string $publicKey, ?string $authKey): ?WireGuardClientConfig
+    private function wConnect(ServerInfo $serverInfo, ProfileConfig $profileConfig, string $userId, string $displayName, DateTimeImmutable $expiresAt, string $vpnProto, string $publicKey, ?string $authKey): ?WireGuardClientConfig
     {
         $nodeNumberList = $profileConfig->onNode();
         shuffle($nodeNumberList);
 
         foreach ($nodeNumberList as $nodeNumber) {
-            if (null === $this->vpnDaemon->nodeInfo($profileConfig->nodeUrl($nodeNumber))) {
+            if (null === $nodeInfo = $this->vpnDaemon->nodeInfo($profileConfig->nodeUrl($nodeNumber))) {
                 // node not available, try next
                 $this->logger->error(sprintf('node "%d" (%s) is not available', $nodeNumber, $profileConfig->nodeUrl($nodeNumber)));
 
                 continue;
             }
+            if ($nodeInfo['maintenance_mode']) {
+                $this->logger->debug(sprintf('node "%d" (%s) in maintenance mode', $nodeNumber, $profileConfig->nodeUrl($nodeNumber)));
+
+                continue;
+            }
             if (null === $serverPublicKey = $serverInfo->publicKey($nodeNumber)) {
                 // node's public key not known, try next
                 $this->logger->error(sprintf('public key of node "%d" (%s) is not set', $nodeNumber, $profileConfig->nodeUrl($nodeNumber)));
 
                 continue;
             }
-            [$ipFour, $ipSix, $err] = $this->getIpAddress($profileConfig, $nodeNumber);
-            if (null !== $err) {
+
+            try {
+                [$ipFour, $ipSix] = $this->getIpAddress($profileConfig, $nodeNumber);
+            } catch (IpException $e) {
                 // no free IP address available on this node, try next
                 $this->logger->warning(sprintf('no free IP address available on node "%d" (%s)', $nodeNumber, $profileConfig->nodeUrl($nodeNumber)));
 
                 continue;
             }
 
+            $nodeInfo = new NodeInfo(
+                $nodeNumber,
+                $profileConfig->nodeUrl($nodeNumber),
+                $profileConfig->hostName($nodeNumber)
+            );
             $this->storage->wPeerAdd($userId, $nodeNumber, $profileConfig->profileId(), $displayName, $publicKey, $ipFour, $ipSix, $this->dateTime, $expiresAt, $authKey);
             $this->vpnDaemon->wPeerAdd($profileConfig->nodeUrl($nodeNumber), $publicKey, $ipFour, $ipSix);
-            $this->connectionHook->connect($userId, $profileConfig->profileId(), 'wireguard', $publicKey, $ipFour, $ipSix, null);
+            $this->connectionHook->connect($nodeInfo, $userId, $profileConfig->profileId(), 'wireguard', $publicKey, $ipFour, $ipSix, null, null);
 
             return new WireGuardClientConfig(
                 $serverInfo->portalUrl(),
                 $nodeNumber,
+                // for WireGuard there's not really a "Prefer TCP", it should
+                // be called "Use TCP" or "Use Proxy", because clients need to
+                // explicity request it. Also, when the server does not support
+                // WireGuard+UDP this should be reflected in the returned VPN
+                // config file...
+                $vpnProto,
                 $profileConfig,
                 $ipFour,
                 $ipSix,
@@ -521,24 +565,34 @@ class ConnectionManager
             );
         }
 
-        // we found no suitable node to connect to...
-        $this->logger->error(sprintf('unable to find a suitable node to connect to for profile "%s"', $profileConfig->profileId()));
+        $this->logger->error(
+            sprintf(
+                'unable to find a suitable node [PROFILE_ID=%s,USER_ID=%s]',
+                $profileConfig->profileId(),
+                $userId
+            )
+        );
 
         return null;
     }
 
-    private function oConnect(ServerInfo $serverInfo, ProfileConfig $profileConfig, string $userId, string $displayName, DateTimeImmutable $expiresAt, bool $preferTcp, ?string $authKey): ?OpenVpnClientConfig
+    private function oConnect(ServerInfo $serverInfo, ProfileConfig $profileConfig, string $userId, string $displayName, DateTimeImmutable $expiresAt, string $vpnProto, ?string $authKey): ?OpenVpnClientConfig
     {
         $nodeNumberList = $profileConfig->onNode();
         shuffle($nodeNumberList);
 
         foreach ($nodeNumberList as $nodeNumber) {
-            if (null === $this->vpnDaemon->nodeInfo($profileConfig->nodeUrl($nodeNumber))) {
+            if (null === $nodeInfo = $this->vpnDaemon->nodeInfo($profileConfig->nodeUrl($nodeNumber))) {
                 // node not available, try next
                 $this->logger->error(sprintf('node "%d" (%s) is not available', $nodeNumber, $profileConfig->nodeUrl($nodeNumber)));
 
                 continue;
             }
+            if ($nodeInfo['maintenance_mode']) {
+                $this->logger->debug(sprintf('node "%d" (%s) in maintenance mode', $nodeNumber, $profileConfig->nodeUrl($nodeNumber)));
+
+                continue;
+            }
 
             $commonName = Base64::encode($this->getRandomBytes());
             $certInfo = $serverInfo->ca()->clientCert($commonName, $profileConfig->profileId(), $expiresAt);
@@ -561,13 +615,18 @@ class ConnectionManager
                 $serverInfo->ca()->caCert(),
                 $serverInfo->tlsCrypt(),
                 $certInfo,
-                $preferTcp,
+                $vpnProto,
                 $expiresAt
             );
         }
 
-        // we found no suitable node to connect to...
-        $this->logger->error(sprintf('unable to find a suitable node to connect to for profile "%s"', $profileConfig->profileId()));
+        $this->logger->error(
+            sprintf(
+                'unable to find a suitable node [PROFILE_ID=%s,USER_ID=%s]',
+                $profileConfig->profileId(),
+                $userId
+            )
+        );
 
         return null;
     }
@@ -614,24 +673,25 @@ class ConnectionManager
     }
 
     /**
-     * Get a free IPv4 and IPv6 address for a specific node belonging to a
-     * profile.
+     * Get a free IPv4 and IPv6 address to assign to a VPN client for a
+     * specific node belonging to a profile.
      *
-     * @return array{0:string,1:string,2:?string}
+     * It does this by obtaining a list of all allocated IPv4 addresses for a
+     * specific profile/node and finding the first address in the prefix not
+     * yet allocated.
+     *
+     * @return array{0:string,1:string}
      */
     private function getIpAddress(ProfileConfig $profileConfig, int $nodeNumber): array
     {
-        // make a list of all allocated IPv4 addresses (the IPv6 address is
-        // based on the IPv4 address)
         $wAllocatedIpFourList = $this->storage->wAllocatedIpFourList($profileConfig->profileId(), $nodeNumber);
-        $ipFourInRangeList = $profileConfig->wRangeFour($nodeNumber)->clientIpListFour();
-        $ipSixInRangeList = $profileConfig->wRangeSix($nodeNumber)->clientIpListSix(\count($ipFourInRangeList));
-        foreach ($ipFourInRangeList as $k => $ipFourInRange) {
-            if (!\in_array($ipFourInRange, $wAllocatedIpFourList, true)) {
-                return [$ipFourInRange, $ipSixInRangeList[$k], null];
-            }
-        }
+        $ipFourPrefix = $profileConfig->wRangeFour($nodeNumber);
+        $ipSixPrefix = $profileConfig->wRangeSix($nodeNumber);
+        [$ipFour, $ipFourIndex] = $ipFourPrefix->freeIpFourAddress($wAllocatedIpFourList);
 
-        return ['', '', 'unable to find a free IP address'];
+        return [
+            $ipFour,
+            $ipSixPrefix->ipSixAddressByIndex($ipFourIndex),
+        ];
     }
 }
