@@ -13,6 +13,4 @@ namespace Vpn\Portal\Exception;
 
 use Exception;
 
-class MigrationException extends Exception
-{
-}
+class MigrationException extends Exception {}
