@@ -13,6 +13,4 @@ namespace Vpn\Portal\Exception;
 
 use Exception;
 
-class ProtocolException extends Exception
-{
-}
+class ProtocolException extends Exception {}
