@@ -31,6 +31,12 @@ class AccessHook extends AbstractHook implements HookInterface
 
     public function afterAuth(Request $request, UserInfo &$userInfo): ?Response
     {
+        // allow "Logout", even when the user has no permission to access the
+        // portal
+        if ('POST' === $request->getRequestMethod() && '/_logout' === $request->getPathInfo()) {
+            return null;
+        }
+
         if (!$userInfo->hasAnyPermission($this->accessPermissionList)) {
             throw new HttpException('your account does not have the required permissions', 403);
         }
