@@ -16,7 +16,6 @@ use Vpn\Portal\Http\JsonResponse;
 use Vpn\Portal\Http\Request;
 use Vpn\Portal\Http\Response;
 use Vpn\Portal\Http\UserInfo;
-use Vpn\Portal\Validator;
 
 class AdminApiAuthModule extends AbstractAuthModule
 {
@@ -43,14 +42,11 @@ class AdminApiAuthModule extends AbstractAuthModule
             return null;
         }
 
-        return new UserInfo(
-            $request->requirePostParameter('user_id', fn (string $s) => Validator::userId($s)),
-            []
-        );
+        return new UserInfo('!admin!api!user!', []);
     }
 
     public function startAuth(Request $request): ?Response
     {
-        return new JsonResponse(['error' => 'authentication required'], ['WWW-Authenticate' => 'Bearer realm="'.$this->authRealm.'"'], 401);
+        return new JsonResponse(['error' => 'authentication required'], ['WWW-Authenticate' => 'Bearer realm="' . $this->authRealm . '"'], 401);
     }
 }
