@@ -31,7 +31,14 @@ class ShibAuthModule extends AbstractAuthModule
         $attributeNameValueList = [];
         foreach ($this->config->permissionAttributeList() as $permissionAttribute) {
             if (null !== $attributeNameValue = $request->optionalHeader($permissionAttribute)) {
-                $attributeNameValueList[$permissionAttribute] = explode(';', $attributeNameValue);
+                $attributeValues = explode(';', $attributeNameValue);
+                if ($this->config->encodedAttributeValues()) {
+                    // urldecode the attribute values as per "encoding" value
+                    // set to "URL"
+                    // @see https://shibboleth.atlassian.net/wiki/spaces/SP3/pages/2065334723/ContentSettings
+                    $attributeValues = array_map('rawurldecode', $attributeValues);
+                }
+                $attributeNameValueList[$permissionAttribute] = $attributeValues;
             }
         }
 
