@@ -21,6 +21,12 @@ class DisabledUserHook extends AbstractHook implements HookInterface
 {
     public function afterAuth(Request $request, UserInfo &$userInfo): ?Response
     {
+        // allow "Logout", even when the user has no permission to access the
+        // portal
+        if ('POST' === $request->getRequestMethod() && '/_logout' === $request->getPathInfo()) {
+            return null;
+        }
+
         if ($userInfo->isDisabled()) {
             throw new HttpException('your account has been disabled by an administrator', 403);
         }
