@@ -13,14 +13,17 @@ namespace Vpn\Portal\Http;
 
 use fkooman\OAuth\Server\Exception\OAuthException;
 use fkooman\OAuth\Server\OAuthServer;
+use Vpn\Portal\LoggerInterface;
 
 class OAuthTokenModule implements ServiceModuleInterface
 {
     private OAuthServer $oauthServer;
+    private LoggerInterface $logger;
 
-    public function __construct(OAuthServer $oauthServer)
+    public function __construct(OAuthServer $oauthServer, LoggerInterface $logger)
     {
         $this->oauthServer = $oauthServer;
+        $this->logger = $logger;
     }
 
     public function init(ServiceInterface $service): void
@@ -33,6 +36,7 @@ class OAuthTokenModule implements ServiceModuleInterface
 
                     return new Response($tokenResponse->getBody(), $tokenResponse->getHeaders(), $tokenResponse->getStatusCode());
                 } catch (OAuthException $e) {
+                    $this->logger->warning(sprintf('OAuth (error=%s description=%s]', $e->getMessage(), $e->getDescription() ?? 'N/A'));
                     $jsonResponse = $e->getJsonResponse();
 
                     return new Response($jsonResponse->getBody(), $jsonResponse->getHeaders(), $jsonResponse->getStatusCode());
