@@ -67,9 +67,8 @@ class VpnPortalModule implements ServiceModuleInterface
             '/home',
             function (Request $request, UserInfo $userInfo): Response {
                 $profileConfigList = $this->config->profileConfigList();
-                $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo);
-
-                $profileSelectList = self::profileSelectList($visibleProfileList);
+                [$availableProfileConfigList, $availableProfileIdList] = self::availableProfileConfigList($profileConfigList, $userInfo);
+                [$rowCount, $profileProtoList] = self::profileProtoList($this->config, $availableProfileConfigList);
 
                 return new HtmlResponse(
                     $this->tpl->render(
@@ -77,10 +76,14 @@ class VpnPortalModule implements ServiceModuleInterface
                         [
                             'maxActiveConfigurations' => $this->config->maxActiveConfigurations(),
                             'numberOfActivePortalConfigurations' => $this->storage->numberOfActivePortalConfigurations($userInfo->userId(), $this->dateTime),
-                            'profileConfigList' => $visibleProfileList,
+                            'profileConfigList' => $this->config->profileConfigList(),
+                            'availableProfileConfigList' => $availableProfileConfigList,
+                            'availableProfileIdList' => $availableProfileIdList,
                             'expiryDate' => $this->sessionExpiry->expiresAt($userInfo)->format('Y-m-d'),
-                            'configList' => self::filterConfigList($this->storage, $userInfo->userId()),
-                            'profileSelectList' => $profileSelectList,
+                            'manualUserConfigList' => self::manualUserConfigList($this->storage, $userInfo->userId()),
+                            'rowCount' => $rowCount,
+                            'profileProtoList' => $profileProtoList,
+                            'allowExpiryExtension' => $this->config->wireGuardConfig()->allowExpiryExtension(),
                         ]
                     )
                 );
@@ -92,26 +95,31 @@ class VpnPortalModule implements ServiceModuleInterface
             function (Request $request, UserInfo $userInfo): Response {
                 $postAction = $request->requirePostParameter(
                     'action',
-                    fn(string $s) => Validator::inSet($s, ['add_config', 'delete_config'])
+                    fn(string $s) => Validator::inSet($s, ['add_config', 'delete_config', 'extend_config'])
                 );
                 switch ($postAction) {
                     case 'add_config':
                         $profileProtoTransport = $request->requirePostParameter('profileId', fn(string $s) => Validator::profileProtoTransport($s));
                         [$profileId, $protoTransport] = Validator::parseProfileProtoTransport($profileProtoTransport);
                         switch ($protoTransport) {
-                            case 'ou':  // OpenVPN UDP
+                            case 'openvpn+udp':
                                 $preferTcp = false;
-                                $clientProtoSupport = ['wireguard' => false, 'openvpn' => true];
+                                $clientProtoSupport = ['openvpn+udp' => true, 'openvpn+tcp' => true, 'wireguard+udp' => false, 'wireguard+tcp' => false];
 
                                 break;
-                            case 'ot':  // OpenVPN TCP
+                            case 'openvpn+tcp':
                                 $preferTcp = true;
-                                $clientProtoSupport = ['wireguard' => false, 'openvpn' => true];
+                                $clientProtoSupport = ['openvpn+udp' => true, 'openvpn+tcp' => true, 'wireguard+udp' => false, 'wireguard+tcp' => false];
 
                                 break;
-                            case 'wu':  // WireGuard UDP
+                            case 'wireguard+udp':
                                 $preferTcp = false;
-                                $clientProtoSupport = ['wireguard' => true, 'openvpn' => false];
+                                $clientProtoSupport = ['openvpn+udp' => false, 'openvpn+tcp' => false, 'wireguard+udp' => true, 'wireguard+tcp' => false];
+
+                                break;
+                            case 'wireguard+tcp':
+                                $preferTcp = true;
+                                $clientProtoSupport = ['openvpn+udp' => false, 'openvpn+tcp' => false, 'wireguard+udp' => false, 'wireguard+tcp' => true];
 
                                 break;
                             default:
@@ -121,6 +129,8 @@ class VpnPortalModule implements ServiceModuleInterface
                         return $this->addConfig($request, $userInfo, $profileId, $preferTcp, $clientProtoSupport);
                     case 'delete_config':
                         return $this->deleteConfig($request, $userInfo);
+                    case 'extend_config':
+                        return $this->extendConfig($request, $userInfo);
                     default:
                         throw new HttpException(sprintf('unsupported action "%s"', $postAction), 400);
                 }
@@ -131,13 +141,13 @@ class VpnPortalModule implements ServiceModuleInterface
             '/account',
             function (Request $request, UserInfo $userInfo): Response {
                 $profileConfigList = $this->config->profileConfigList();
-                $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo);
+                [$availableProfileConfigList,] = self::availableProfileConfigList($profileConfigList, $userInfo);
 
                 return new HtmlResponse(
                     $this->tpl->render(
                         'vpnPortalAccount',
                         [
-                            'profileConfigList' => $visibleProfileList,
+                            'availableProfileConfigList' => $availableProfileConfigList,
                             'showPermissions' => $this->config->showPermissions(),
                             'userInfo' => $userInfo,
                             'showRefreshButton' => $this->permissionSourceManager->hasPermissionSources(),
@@ -191,9 +201,9 @@ class VpnPortalModule implements ServiceModuleInterface
     }
 
     /**
-     * @return list<array{auth_key: null, connection_id: string, display_name: string, expires_at: DateTimeImmutable, ip_four?: string, ip_six?: string, node_number: int, profile_id: string}>
+     * @return list<array{connection_id:string,display_name:string,expires_at:\DateTimeImmutable,ip_four?:string,ip_six?:string,node_number:int,profile_id:string,vpn_proto:string}>
      */
-    public static function filterConfigList(Storage $storage, string $userId): array
+    public static function manualUserConfigList(Storage $storage, string $userId): array
     {
         $configList = [];
         foreach ($storage->oCertInfoListByUserId($userId) as $oCertInfo) {
@@ -202,10 +212,12 @@ class VpnPortalModule implements ServiceModuleInterface
             }
             $connectionId = $oCertInfo['common_name'];
             unset($oCertInfo['common_name']);
+            unset($oCertInfo['auth_key']);
             $configList[] = array_merge(
                 $oCertInfo,
                 [
                     'connection_id' => $connectionId,
+                    'vpn_proto' => 'openvpn',
                 ]
             );
         }
@@ -216,10 +228,12 @@ class VpnPortalModule implements ServiceModuleInterface
             }
             $connectionId = $wPeerInfo['public_key'];
             unset($wPeerInfo['public_key']);
+            unset($wPeerInfo['auth_key']);
             $configList[] = array_merge(
                 $wPeerInfo,
                 [
                     'connection_id' => $connectionId,
+                    'vpn_proto' => 'wireguard',
                 ]
             );
         }
@@ -228,7 +242,7 @@ class VpnPortalModule implements ServiceModuleInterface
     }
 
     /**
-     * @param array{wireguard:bool,openvpn:bool} $clientProtoSupport
+     * @param array{openvpn+udp:bool,openvpn+tcp:bool,wireguard+udp:bool,wireguard+tcp:bool} $clientProtoSupport
      */
     private function addConfig(Request $request, UserInfo $userInfo, string $profileId, bool $preferTcp, array $clientProtoSupport): Response
     {
@@ -243,12 +257,12 @@ class VpnPortalModule implements ServiceModuleInterface
 
         $displayName = $request->requirePostParameter('displayName', fn(string $s) => Validator::displayName($s));
         $profileConfigList = $this->config->profileConfigList();
-        $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo);
+        [, $availableProfileIdList] = self::availableProfileConfigList($profileConfigList, $userInfo);
 
         // make sure the profileId is in the list of allowed profiles for this
         // user, it would not result in the ability to use the VPN, but
         // better prevent it early
-        if (!$this->isAllowedProfile($visibleProfileList, $profileId)) {
+        if (!in_array($profileId, $availableProfileIdList, true)) {
             throw new HttpException('no permission to download a configuration for this profile', 403);
         }
 
@@ -277,7 +291,41 @@ class VpnPortalModule implements ServiceModuleInterface
             $request->requirePostParameter('connectionId', fn(string $s) => Validator::connectionId($s))
         );
 
-        return new RedirectResponse($request->getRootUri() . 'home');
+        return new RedirectResponse($request->getRootUri() . 'home#active-configurations');
+    }
+
+    /**
+     * Extend the validity of the WireGuard configuration to match
+     * sessionExpiry. This allows users to "extend" the duration of the
+     * configuration without obtaining a new one and importing it in their
+     * VPN application.
+     */
+    private function extendConfig(Request $request, UserInfo $userInfo): Response
+    {
+        if (!$this->config->wireGuardConfig()->allowExpiryExtension()) {
+            throw new HttpException('extending the expiry of WireGuard configuration files not allowed', 400);
+        }
+
+        $connectionId = $request->requirePostParameter('connectionId', fn(string $s) => Validator::connectionId($s));
+        if (null === $wPeerInfo = $this->storage->wPeerInfo($connectionId)) {
+            throw new HttpException('peer does not or no longer exist', 400);
+        }
+        if ($userInfo->userId() !== $wPeerInfo['user_id']) {
+            throw new HttpException('peer configuration does not belong to this user', 403);
+        }
+
+        // we MUST make sure the user still is allowed to use the profile the
+        // configuration belongs to...
+        $profileConfigList = $this->config->profileConfigList();
+        [, $availableProfileIdList] = self::availableProfileConfigList($profileConfigList, $userInfo);
+        if (!in_array($wPeerInfo['profile_id'], $availableProfileIdList, true)) {
+            throw new HttpException('user no longer has access to this profile', 403);
+        }
+
+        $expiresAt = $this->sessionExpiry->expiresAt($userInfo);
+        $this->storage->wPeerSetExpiresAt($connectionId, $expiresAt);
+
+        return new RedirectResponse($request->getRootUri() . 'home#active-configurations');
     }
 
     private function clientConfigResponse(ClientConfigInterface $clientConfig, string $serverName, string $profileId, string $displayName, string $secretKey): Response
@@ -320,74 +368,70 @@ class VpnPortalModule implements ServiceModuleInterface
      *
      * @param array<\Vpn\Portal\Cfg\ProfileConfig> $profileConfigList
      *
-     * @return array<\Vpn\Portal\Cfg\ProfileConfig>
+     * @return array{0:array<\Vpn\Portal\Cfg\ProfileConfig>,1:array<string>}
      */
-    private static function filterProfileList(array $profileConfigList, UserInfo $userInfo): array
+    private static function availableProfileConfigList(array $profileConfigList, UserInfo $userInfo): array
     {
-        $filteredProfileConfigList = [];
+        $availableProfileConfigList = [];
+        $availableProfileIdList = [];
         foreach ($profileConfigList as $profileConfig) {
+            if ($profileConfig->hideProfile()) {
+                // do not allow connections to this profile when the profile is
+                // hidden
+                continue;
+            }
             if (null !== $aclPermissionList = $profileConfig->aclPermissionList()) {
                 if (!$userInfo->hasAnyPermission($aclPermissionList)) {
                     continue;
                 }
             }
 
-            $filteredProfileConfigList[] = $profileConfig;
+            $availableProfileIdList[] = $profileConfig->profileId();
+            $availableProfileConfigList[] = $profileConfig;
         }
 
-        return $filteredProfileConfigList;
-    }
-
-    /**
-     * @param array<\Vpn\Portal\Cfg\ProfileConfig> $profileConfigList
-     */
-    private static function isAllowedProfile(array $profileConfigList, string $profileId): bool
-    {
-        foreach ($profileConfigList as $profileConfig) {
-            if ($profileId === $profileConfig->profileId()) {
-                return true;
-            }
-        }
-
-        return false;
+        return [$availableProfileConfigList, $availableProfileIdList];
     }
 
     /**
      * @param array<\Vpn\Portal\Cfg\ProfileConfig> $profileConfigList
      *
-     * @return array{rowCount:int,profileList:array<array{profileId:string,displayName:string,protoTransportList:array<string>}>}
+     * @return array{0:int,1:array<array{profileId:string,displayName:string,protoTransportList:array<string>}>}
      */
-    private static function profileSelectList(array $profileConfigList): array
+    private static function profileProtoList(Config $config, array $profileConfigList): array
     {
-        $profileSelectList = [
-            'profileList' => [],
-        ];
-
+        $profileProtoList = [];
         $rowCount = 0;
         foreach ($profileConfigList as $profileConfig) {
-            $rowCount++;
             $protoTransportList = [];
             if ($profileConfig->oSupport()) {
                 if (0 !== count($profileConfig->oUdpPortList())) {
-                    $protoTransportList[] = 'ou';
+                    $protoTransportList[] = 'openvpn+udp';
                 }
                 if (0 !== count($profileConfig->oTcpPortList())) {
-                    $protoTransportList[] = 'ot';
+                    $protoTransportList[] = 'openvpn+tcp';
                 }
             }
             if ($profileConfig->wSupport()) {
-                $protoTransportList[] = 'wu';
+                if (!$config->wireGuardConfig()->onlyProxy()) {
+                    $protoTransportList[] = 'wireguard+udp';
+                }
+                if ($config->wireGuardConfig()->enableProxy()) {
+                    $protoTransportList[] = 'wireguard+tcp';
+                }
             }
-            $rowCount += count($protoTransportList);
-            $profileSelectList['profileList'][] = [
+            if (0 === count($protoTransportList)) {
+                // do not add the profile to the list if it has no protocols
+                continue;
+            }
+            $rowCount += count($protoTransportList) + 1;
+            $profileProtoList[] = [
                 'profileId' => $profileConfig->profileId(),
                 'displayName' => $profileConfig->displayName(),
                 'protoTransportList' => $protoTransportList,
             ];
         }
 
-        $profileSelectList['rowCount'] = $rowCount;
-
-        return $profileSelectList;
+        return [$rowCount, $profileProtoList];
     }
 }
