@@ -78,8 +78,8 @@ class Ip
                 gmp_and(
                     $this->ipAddress,
                     gmp_and(
-                        gmp_sub(gmp_pow(2, $this->addressBits()), 1),
-                        gmp_sub(gmp_pow(2, $this->addressBits()), gmp_pow(2, $this->addressBits() - $this->ipPrefix))
+                        gmp_sub(self::gmpPowTwo($this->addressBits()), 1),
+                        gmp_sub(self::gmpPowTwo($this->addressBits()), self::gmpPowTwo($this->addressBits() - $this->ipPrefix))
                     )
                 ),
                 $this->addressBits()
@@ -92,8 +92,8 @@ class Ip
     {
         return self::toAddress(
             gmp_xor(
-                gmp_sub(gmp_pow(2, $this->addressBits()), 1),
-                gmp_sub(gmp_pow(2, $this->addressBits() - $this->ipPrefix), 1),
+                gmp_sub(self::gmpPowTwo($this->addressBits()), 1),
+                gmp_sub(self::gmpPowTwo($this->addressBits() - $this->ipPrefix), 1),
             ),
             $this->addressBits()
         );
@@ -140,7 +140,7 @@ class Ip
             gmp_add(
                 self::fromAddress($this->network()->address()),
                 gmp_sub(
-                    gmp_pow(2, $this->addressBits() - $this->prefix()),
+                    self::gmpPowTwo($this->addressBits() - $this->prefix()),
                     1
                 )
             ),
@@ -168,7 +168,7 @@ class Ip
 
         $prefixBits = $this->ipPrefix + 1;
         $netIp = $this->network();
-        $noOfHosts = gmp_pow(2, $this->addressBits() - $prefixBits);
+        $noOfHosts = self::gmpPowTwo($this->addressBits() - $prefixBits);
 
         return [
             new self(
@@ -206,7 +206,7 @@ class Ip
         $netIp = $this->network();
         $splitRanges = [];
         for ($i = 0; $i < $networkCount; ++$i) {
-            $noOfHosts = gmp_pow(2, $this->addressBits() - $prefixBits);
+            $noOfHosts = self::gmpPowTwo($this->addressBits() - $prefixBits);
             $netAddress = gmp_add(gmp_mul($i, $noOfHosts), self::fromAddress($netIp->address()));
             $splitRanges[] = new self($netAddress, $prefixBits, $this->ipFamily);
         }
@@ -265,7 +265,7 @@ class Ip
             throw new IpException('network not big enough to create a list of client IPs');
         }
 
-        $prefixMaxNoOfHosts = gmp_pow(2, 128 - $this->ipPrefix);
+        $prefixMaxNoOfHosts = self::gmpPowTwo(128 - $this->ipPrefix);
         if (gmp_cmp($i, $prefixMaxNoOfHosts) > 0) {
             throw new IpException(sprintf('prefix "/%d" does not contain "%d" hosts', $this->ipPrefix, $i));
         }
@@ -322,7 +322,7 @@ class Ip
 
         // make sure we do not specify a "maxNumberOfHosts" that is bigger
         // than the prefix we have
-        $prefixMaxNoOfHosts = gmp_sub(gmp_pow(2, 128 - $this->ipPrefix), 3);
+        $prefixMaxNoOfHosts = gmp_sub(self::gmpPowTwo(128 - $this->ipPrefix), 3);
         if (gmp_cmp($maxNoOfHosts, $prefixMaxNoOfHosts) > 0) {
             throw new IpException(sprintf('prefix "/%d" does not contain "%d" hosts', $this->ipPrefix, $maxNoOfHosts));
         }
@@ -426,4 +426,22 @@ class Ip
             )
         );
     }
+
+    /**
+     * Workaround PHP bug in gmp_pow() where the exponent all of a sudden
+     * needs to be <64.
+     *
+     * This issue was introducted in PHP 8.2.26 and 8.3.14 (and perhaps in
+     * PHP 8.4.0?)
+     *
+     * @see https://github.com/php/php-src/issues/16870
+     * @see https://github.com/phpipam/phpipam/commit/2414f8606bf77c6ed41364e780d1fb31150017d5
+     */
+    private static function gmpPowTwo(int $e): GMP
+    {
+        $r = gmp_init(0);
+        gmp_setbit($r, $e);
+
+        return $r;
+    }
 }
