@@ -11,11 +11,11 @@ declare(strict_types=1);
 
 namespace Vpn\Portal;
 
-use Exception;
 use PDO;
 use PDOException;
 use RangeException;
 use RuntimeException;
+use Throwable;
 use Vpn\Portal\Exception\MigrationException;
 
 class Migration
@@ -84,7 +84,7 @@ class Migration
                     }
                 }
             }
-        } catch (Exception $e) {
+        } catch (Throwable $e) {
             // something went wrong that was not related to SQL queries
             self::unlock($db);
 
