@@ -19,9 +19,20 @@ use Vpn\Portal\Json;
 
 class VpnClientDb extends SimpleClientDb
 {
-    public function __construct(string $jsonClientDbFile)
+    /**
+     * @param array<string> $appSets
+     */
+    public function __construct(string $jsonClientDbFile, array $appSets)
     {
-        $this->defaultClientRegistration();
+        if (in_array('eduVPN', $appSets, true)) {
+            $this->eduVPN();
+        }
+        if (in_array('LC', $appSets, true)) {
+            $this->LC();
+        }
+        if (in_array('govVPN', $appSets, true)) {
+            $this->govVPN();
+        }
         $this->fromJsonFile($jsonClientDbFile);
     }
 
@@ -36,11 +47,8 @@ class VpnClientDb extends SimpleClientDb
         }
     }
 
-    private function defaultClientRegistration(): void
+    private function eduVPN(): void
     {
-        //
-        // eduVPN
-        //
         $this->add(
             new ClientInfo(
                 'org.eduvpn.app.windows',
@@ -54,8 +62,12 @@ class VpnClientDb extends SimpleClientDb
         $this->add(
             new ClientInfo(
                 'org.eduvpn.app.android',
-                // should have been org.eduvpn.app.android:/api/callback
-                ['org.eduvpn.app:/api/callback'],
+                [
+                    // we want the scheme of the redirect_uri to match the
+                    // client_id, initially we made a mistake on Android...
+                    'org.eduvpn.app:/api/callback',
+                    'org.eduvpn.app.android:/api/callback',
+                ],
                 null,
                 'eduVPN for Android',
                 true,
@@ -92,10 +104,10 @@ class VpnClientDb extends SimpleClientDb
                 new Scope('config')
             )
         );
+    }
 
-        //
-        // Let's Connect!
-        //
+    private function LC(): void
+    {
         $this->add(
             new ClientInfo(
                 'org.letsconnect-vpn.app.windows',
@@ -109,8 +121,12 @@ class VpnClientDb extends SimpleClientDb
         $this->add(
             new ClientInfo(
                 'org.letsconnect-vpn.app.android',
-                // should have been org.eduvpn.app.android:/api/callback
-                ['org.letsconnect-vpn.app:/api/callback'],
+                [
+                    // we want the scheme of the redirect_uri to match the
+                    // client_id, initially we made a mistake on Android...
+                    'org.letsconnect-vpn.app:/api/callback',
+                    'org.letsconnect-vpn.app.android:/api/callback',
+                ],
                 null,
                 'Let\'s Connect! for Android',
                 true,
@@ -148,4 +164,63 @@ class VpnClientDb extends SimpleClientDb
             )
         );
     }
+
+    private function govVPN(): void
+    {
+        $this->add(
+            new ClientInfo(
+                'org.govvpn.app.windows',
+                ['http://127.0.0.1:{PORT}/callback', 'http://[::1]:{PORT}/callback'],
+                null,
+                'govVPN for Windows',
+                true,
+                new Scope('config')
+            )
+        );
+        $this->add(
+            new ClientInfo(
+                'org.govvpn.app.android',
+                [
+                    // we want the scheme of the redirect_uri to match the
+                    // client_id, initially we made a mistake on Android...
+                    'org.govvpn.app:/api/callback',
+                    'org.govvpn.app.android:/api/callback',
+                ],
+                null,
+                'govVPN for Android',
+                true,
+                new Scope('config')
+            )
+        );
+        $this->add(
+            new ClientInfo(
+                'org.govvpn.app.ios',
+                ['org.govvpn.app.ios:/api/callback'],
+                null,
+                'govVPN for iOS',
+                true,
+                new Scope('config')
+            )
+        );
+        $this->add(
+            new ClientInfo(
+                'org.govvpn.app.macos',
+                ['http://127.0.0.1:{PORT}/callback', 'http://[::1]:{PORT}/callback'],
+                null,
+                'govVPN for macOS',
+                true,
+                new Scope('config')
+            )
+        );
+        $this->add(
+            new ClientInfo(
+                'org.govvpn.app.linux',
+                ['http://127.0.0.1:{PORT}/callback', 'http://[::1]:{PORT}/callback'],
+                null,
+                'govVPN for Linux',
+                true,
+                new Scope('config')
+            )
+        );
+    }
 }
