@@ -22,9 +22,9 @@ use fkooman\OAuth\Server\StorageInterface;
  */
 class VpnOAuthServer extends OAuthServer
 {
-    public function __construct(StorageInterface $storage, ClientDbInterface $clientDb, SignerInterface $signer, DateInterval $accessTokenExpiry)
+    public function __construct(StorageInterface $storage, ClientDbInterface $clientDb, SignerInterface $signer, DateInterval $accessTokenExpiry, string $issuerIdentity)
     {
-        parent::__construct($storage, $clientDb, $signer);
+        parent::__construct($storage, $clientDb, $signer, $issuerIdentity);
         $this->accessTokenExpiry = $accessTokenExpiry;
     }
 }
