@@ -14,12 +14,12 @@ namespace Vpn\Portal;
 interface PermissionSourceInterface
 {
     /**
-     * Get current attributes for users directly from the source.
+     * Get current permissions for users directly from the source.
      *
-     * If no attributes are available, or the user no longer exists, an empty
+     * If no permissions are available, or the user no longer exists, an empty
      * array is returned.
      *
      * @return array<string>
      */
-    public function attributesForUser(string $userId): array;
+    public function permissionsForUser(string $userId): array;
 }
