@@ -197,22 +197,6 @@ class Protocol
         );
     }
 
-    /**
-     * Helper function to determine whether the protocol is WireGuard.
-     */
-    private static function isWireGuard(string $p): bool
-    {
-        return 'wireguard+udp' === $p || 'wireguard+tcp' === $p;
-    }
-
-    /**
-     * Helper function to determine whether the protocol is OpenVPN.
-     */
-    private static function isOpenVpn(string $p): bool
-    {
-        return 'openvpn+udp' === $p || 'openvpn+tcp' === $p;
-    }
-
     /**
      * Helper function to determine whether the transport is TCP.
      */
