@@ -27,13 +27,13 @@ class ScriptConnectionHook implements ConnectionHookInterface
         $this->scriptPath = self::verifyFile($scriptPath);
     }
 
-    /**
-     * @throws \Vpn\Portal\Exception\ConnectionHookException
-     */
-    public function connect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp): void
+    public function connect(NodeInfo $nodeInfo, string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp, ?IpInfo $ipInfo): void
     {
         $envVarList = [
             'EVENT' => 'C',
+            'NODE_NUMBER' => (string) $nodeInfo->nodeNumber(),
+            'NODE_URL' => $nodeInfo->nodeUrl(),
+            'NODE_HOST_NAME' => $nodeInfo->hostName(),
             'USER_ID' => $userId,
             'PROFILE_ID' => $profileId,
             'PROTO' => $vpnProto,
@@ -44,6 +44,10 @@ class ScriptConnectionHook implements ConnectionHookInterface
         if (null !== $originatingIp) {
             $envVarList['ORIGINATING_IP'] = $originatingIp;
         }
+        if (null !== $ipInfo) {
+            $envVarList['GEO_IP_CC'] = $ipInfo->countryCode();
+            $envVarList['GEO_IP_URI'] = $ipInfo->geoUri();
+        }
 
         $this->exec(
             sprintf(
@@ -54,13 +58,13 @@ class ScriptConnectionHook implements ConnectionHookInterface
         );
     }
 
-    /**
-     * @throws \Vpn\Portal\Exception\ConnectionHookException
-     */
-    public function disconnect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, int $bytesIn, int $bytesOut): void
+    public function disconnect(NodeInfo $nodeInfo, string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, int $bytesIn, int $bytesOut): void
     {
         $envVarList = [
             'EVENT' => 'D',
+            'NODE_NUMBER' => (string) $nodeInfo->nodeNumber(),
+            'NODE_URL' => $nodeInfo->nodeUrl(),
+            'NODE_HOST_NAME' => $nodeInfo->hostName(),
             'USER_ID' => $userId,
             'PROFILE_ID' => $profileId,
             'PROTO' => $vpnProto,
