@@ -14,12 +14,13 @@ namespace Vpn\Portal;
 use DateInterval;
 use DateTimeImmutable;
 use PDO;
+use RuntimeException;
 use Vpn\Portal\Cfg\DbConfig;
 use Vpn\Portal\Http\UserInfo;
 
 class Storage
 {
-    public const CURRENT_SCHEMA_VERSION = '2023011801';
+    public const CURRENT_SCHEMA_VERSION = '2024052801';
 
     private PDO $db;
 
@@ -56,6 +57,16 @@ class Storage
         $this->db = $db;
     }
 
+    public function driverName(): string
+    {
+        $driverName = $this->db->getAttribute(PDO::ATTR_DRIVER_NAME);
+        if (!is_string($driverName)) {
+            throw new RuntimeException('unable to determine PDO driver');
+        }
+
+        return $driverName;
+    }
+
     public function dbPdo(): PDO
     {
         return $this->db;
@@ -157,6 +168,23 @@ class Storage
         $stmt->execute();
     }
 
+    public function wPeerSetExpiresAt(string $publicKey, DateTimeImmutable $expiresAt): void
+    {
+        $stmt = $this->db->prepare(
+            <<< 'SQL'
+                UPDATE
+                    wg_peers
+                SET
+                    expires_at = :expires_at
+                WHERE
+                    public_key = :public_key
+                SQL
+        );
+        $stmt->bindValue(':public_key', $publicKey, PDO::PARAM_STR);
+        $stmt->bindValue(':expires_at', $expiresAt->format(DateTimeImmutable::ATOM), PDO::PARAM_STR);
+        $stmt->execute();
+    }
+
     /**
      * Get a list of IPv4 addresses already in use by a specific node belonging
      * to a profile.
@@ -422,7 +450,7 @@ class Storage
         $stmt->bindValue(':last_seen', $lastSeen->format(DateTimeImmutable::ATOM), PDO::PARAM_STR);
         $stmt->bindValue(':permission_list', self::permissionListToString($userInfo->permissionList()), PDO::PARAM_STR);
         $stmt->bindValue(':auth_data', $userInfo->authData(), PDO::PARAM_STR | PDO::PARAM_NULL);
-        $stmt->bindValue(':is_disabled', false, PDO::PARAM_BOOL);
+        $stmt->bindValue(':is_disabled', $userInfo->isDisabled(), PDO::PARAM_BOOL);
         $stmt->execute();
     }
 
@@ -459,6 +487,44 @@ class Storage
         return $userList;
     }
 
+    /**
+     * Return only users that were last seen before the provided "last seen".
+     *
+     * @return array<\Vpn\Portal\Http\UserInfo>
+     */
+    public function userListLastSeenBefore(DateTimeImmutable $lastSeen): array
+    {
+        $stmt = $this->db->prepare(
+            <<< 'SQL'
+                    SELECT
+                        user_id,
+                        permission_list,
+                        auth_data,
+                        is_disabled
+                    FROM
+                        users
+                    WHERE
+                        last_seen < :last_seen
+                    ORDER BY
+                        user_id
+                SQL
+        );
+        $stmt->bindValue(':last_seen', $lastSeen->format(DateTimeImmutable::ATOM), PDO::PARAM_STR);
+        $stmt->execute();
+
+        $userList = [];
+        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $resultRow) {
+            $userList[] = new UserInfo(
+                (string) $resultRow['user_id'],
+                self::stringToPermissionList((string) $resultRow['permission_list']),
+                null === $resultRow['auth_data'] ? null : (string) $resultRow['auth_data'],
+                (bool) $resultRow['is_disabled']
+            );
+        }
+
+        return $userList;
+    }
+
     public function userInfo(string $userId): ?UserInfo
     {
         $stmt = $this->db->prepare(
