@@ -11,15 +11,11 @@ declare(strict_types=1);
 
 namespace Vpn\Portal;
 
-use RuntimeException;
-
 class SysLogger implements LoggerInterface
 {
     public function __construct(string $appName)
     {
-        if (false === openlog($appName, LOG_ODELAY, LOG_USER)) {
-            throw new RuntimeException('unable to open syslog');
-        }
+        openlog($appName, LOG_ODELAY, LOG_USER);
     }
 
     public function __destruct()
