@@ -3,8 +3,7 @@
 <?php /** @var string $requestRoot */?>
 <?php /** @var bool $showLogoutButton */?>
 <?php if ($showLogoutButton): ?>
-
-<form class="logout" method="post" action="<?=$this->e($requestRoot); ?>_logout">
+<form method="post" action="<?=$this->e($requestRoot); ?>_logout">
     <button type="submit"><?=$this->t('Sign Out'); ?></button>
 </form>
 <?php endif; ?>
