@@ -1,7 +1,7 @@
 <?php declare(strict_types=1); ?>
 <?php /** @var \Vpn\Portal\Tpl $this */?>
 <?php /** @var bool $showPermissions */?>
-<?php /** @var array<\Vpn\Portal\Cfg\ProfileConfig> $profileConfigList */?>
+<?php /** @var array<\Vpn\Portal\Cfg\ProfileConfig> $availableProfileConfigList */?>
 <?php /** @var \Vpn\Portal\Http\UserInfo $userInfo */?>
 <?php /** @var array<\fkooman\OAuth\Server\Authorization> $authorizationList */?>
 <?php /** @var string $authModule */?>
@@ -48,11 +48,11 @@
         <tr>
             <th><?=$this->t('Available Profiles'); ?></th>
             <td>
-<?php if (0 === count($profileConfigList)): ?>
+<?php if (0 === count($availableProfileConfigList)): ?>
                 <em><?=$this->t('Your account does not have access to any VPN profile.'); ?></em>
 <?php else: ?>
                 <ul>
-                    <?php foreach ($profileConfigList as $profileConfig): ?>
+                    <?php foreach ($availableProfileConfigList as $profileConfig): ?>
                         <li><?=$this->e($profileConfig->displayName()); ?></li>
                     <?php endforeach; ?>
                 </ul>
@@ -65,10 +65,11 @@
     <h2><?=$this->t('Authorized Applications'); ?></h2>
     <p>
         <?=$this->t('The list of applications you authorized to create a VPN connection.'); ?>
+        <?=$this->t('Sorted by "Last Used", most recently used first.');?>
     </p>
     <table class="tbl">
         <thead>
-            <tr><th><?=$this->t('Name'); ?></th><th><?=$this->t('Authorized On'); ?></th><th><?=$this->t('Expires On'); ?></th><th></th></tr>
+            <tr><th><?=$this->t('Name'); ?></th><th><?=$this->t('Authorized On'); ?></th><th><?=$this->t('Expires On'); ?></th><th><?=$this->t('Last Used'); ?></th><th></th></tr>
         </thead>
         <tbody>
 <?php foreach ($authorizationList as $authorizationInfo): ?>
@@ -76,6 +77,7 @@
                 <td><span title="<?=$this->e($authorizationInfo->clientId()); ?>"><?=$this->clientIdToDisplayName($authorizationInfo->clientId()); ?></span></td>
                 <td><span title="<?=$this->d($authorizationInfo->authorizedAt()); ?>"><?=$this->d($authorizationInfo->authorizedAt(), 'Y-m-d'); ?></span></td>
                 <td><span title="<?=$this->d($authorizationInfo->expiresAt()); ?>"><?=$this->d($authorizationInfo->expiresAt(), 'Y-m-d'); ?></span></td>
+                <td><span title="<?=$this->d($authorizationInfo->lastUsed()); ?>"><?=$this->d($authorizationInfo->lastUsed(), 'Y-m-d'); ?></span></td>
                 <td class="text-right">
                     <form class="frm" method="post" action="removeClientAuthorization">
                         <input type="hidden" name="auth_key" value="<?=$this->e($authorizationInfo->authKey()); ?>">
