@@ -5,10 +5,10 @@
 <?php $this->start('content'); ?>
     <h2><?= $this->t('WireGuard Configuration'); ?></h2>
 <?php if (null !== $qrCode = $wireGuardClientConfig->getQr()): ?>
-    <p>
-<?=$this->t('Use the WireGuard app on your mobile device to scan this QR code.'); ?>
-    </p>
-<?=$qrCode; ?>
+    <figure>
+        <figcaption><?=$this->t('Use the WireGuard app on your mobile device to scan this QR code.'); ?></figcaption>
+        <?=$qrCode; ?>
+    </figure>
 <?php endif; ?>
     <p>
 <?=$this->t('Import or copy/paste this configuration to your WireGuard application.'); ?>
