@@ -255,7 +255,7 @@ try {
     $service->addModule($adminPortalModule);
 
     if (null === $issuerIdentity = $config->apiConfig()->issuerIdentity()) {
-        $issuerIdentity = $request->getOrigin() . '/';
+        $issuerIdentity = $request->getOrigin();
     }
 
     // OAuth module
@@ -278,7 +278,7 @@ try {
     $htmlResponse = $service->run($request);
     $sessionBackend->stop();
     $htmlResponse->send();
-} catch (Exception $e) {
+} catch (Throwable $e) {
     $logger->error($e->getMessage());
     $response = new Response($e->getMessage(), ['Content-Type' => 'text/plain'], 500);
     if (null !== $tpl) {
