@@ -59,7 +59,7 @@ try {
     $storage = new Storage($config->dbConfig($baseDir));
 
     if (null === $issuerIdentity = $config->apiConfig()->issuerIdentity()) {
-        $issuerIdentity = $request->getOrigin() . '/';
+        $issuerIdentity = $request->getOrigin();
     }
 
     // OAuth module
@@ -72,11 +72,12 @@ try {
     );
 
     $oauthModule = new OAuthTokenModule(
-        $oauthServer
+        $oauthServer,
+        $logger
     );
     $service->addModule($oauthModule);
     $service->run($request)->send();
-} catch (Exception $e) {
+} catch (Throwable $e) {
     $logger->error($e->getMessage());
     $response = new JsonResponse(['error' => $e->getMessage()], [], 500);
     $response->send();
