@@ -36,7 +36,7 @@ try {
 
     $response = new JsonResponse($jsonData, ['Cache-Control' => 'no-store']);
     $response->send();
-} catch (Exception $e) {
+} catch (Throwable $e) {
     $response = new JsonResponse(['error' => $e->getMessage()], [], 500);
     $response->send();
 }
